@@ -3,7 +3,6 @@ from .so4gp import DataGP
 from .so4gp import GI
 from .so4gp import GP
 from .so4gp import TimeLag
-from .so4gp import gibitmap
 from .so4gp import inv
 
 from .so4gp import gend
@@ -21,4 +20,9 @@ from .so4gp import acogps
 from .so4gp import gagps
 from .so4gp import psogps
 from .so4gp import hcgps
-from .so4gp import rsgps
\ No newline at end of file
+from .so4gp import rsgps
+
+from .so4gp import get_num_cores
+from .so4gp import get_slurm_cores
+from .so4gp import write_file
+from .so4gp import plot_curve
